qq_plot — QuadratiK 1.0.0 documentation

Skip to main content
`Ctrl`+`K`

# qq_plot

QuadratiK.tools.qq_plot(x, y=None, dist='norm')

  The function qq_plot is used to create a quantile-quantile plot, either for a single sample or for two samples.

  ## Parameters

  > xnumpy.ndarray

  >   The x parameter represents the data for which you want to create a QQ plot. It can be a single variable or an array-like object containing multiple variables

  > ynumpy.ndarray, optional

  >   The parameter y is an optional argument that represents the second sample for a two-sample QQ plot. If provided, the function will generate a QQ plot comparing the two samples

  > diststr, optional

  >   Supports all the scipy.stats.distributions. The dist parameter specifies the distribution to compare the data against in the QQ plot. By default, it is set to “norm” which represents the normal distribution. However, you can specify a different distribution if you want to compare the data against a different distribution. Defaults to “norm”.

  ## Returns

  > Returns QQ plots.

  ## Examples

      >>> import numpy as np
      >>> from QuadratiK.tools import qq_plot
      >>> np.random.seed(42)
      >>> X = np.random.randn(100,4)
      >>> qq_plot(X)